/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;

/* section: NIM_merge_TYPES */
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw;
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getDispatcher__L29cJgZ3WUDC7PfTSciv49cw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genConv__NQxHzfwHfEh0YK3SZMpnIA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* d, NIM_BOOL downcast, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag, sameMethodBucket__leCAOmQx9bAqhpFuS2yXNVQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, NIM_BOOL multiMethods);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__3isNyHKb0U1OCnClmflXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTypeOrNil__3isNyHKb0U1OCnClmflXSg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, attachDispatcher__IMb6oKnI7Z7MRoHmAsuW3g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dispatcher);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, fixupDispatcher__UnAnE9bJg1GOV6YuCjrHPfg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* meth, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___75vsOXLrqmx5LmVlMWaymw)(NI16 x);
N_LIB_PRIVATE N_NIMCALL(void, checkMethodEffects__r9asNVglvzXEd9bIUN8ENKaA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* branch);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createDispatcher__L29cJgZ3WUDC7PfTSciv49cw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, copySym__lIu8wX6Beq6dBJgESOFFjg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, copyType__4O4aYoscFPo2FRSh4rP9ayg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL keepId);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, relevantCol__VyTMs9bvAKVadESEVcZjTAg)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ* methods, NI col);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, sortBucket__deGdLjtRTwqb9cmLid4ujVA)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** a, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols);
N_LIB_PRIVATE N_NIMCALL(NI, cmpSignatures__rUZr5XojrKzIvIaAqdTDew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, genDispatcher__fxC8K5IpbgysfOghKezEGw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tySequence__DfgJFJEYoj4YBAHLZPl5lQ* methods, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_2, "cgmeth.nim(42, 14) `sfDispatcher in result.flags` ", 50);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_3, "cgmeth.genConv: no upcast allowed", 33);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_5, "/home/runner/work/nightlies/nightlies/nim/compiler/cgmeth.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_4 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 27),
((NI) 32)}
;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_6, "cgmeth.genConv: no downcast allowed", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_7 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 32),
((NI) 21)}
;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_8, "\'", 1);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_9, "\' lacks a dispatcher", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_10 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 54),
((NI) 14)}
;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_11, "method has lock level $1, but another method has $2", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_12 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 152),
((NI) 13)}
;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_13, "method is not a base", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_14 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 174),
((NI) 18)}
;
extern TNimType NTI__bWZXqEvLFwhLvAqSRoFNgQ_;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_15, "invalid declaration order; cannot attach \'", 42);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_16, "\' to method defined here: ", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_17 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 185),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__zwdrTKOAAM6OvWnXdBD4GQ_18 = {((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_5),
((NI) 188),
((NI) 11)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_19, "and", 3);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_20, "of", 2);
STRING_LITERAL(TM__zwdrTKOAAM6OvWnXdBD4GQ_21, "chckNilDisp", 11);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getDispatcher__L29cJgZ3WUDC7PfTSciv49cw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*s).ast);
		if (!(((NI) 8) < T3_)) goto LA4_;
		result = (*(*(*s).ast)._kind_6.sons->data[((NI) 8)])._kind_4.sym;
		{
			if (!!((((*result).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 29))&63U)))!=0))) goto LA8_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_2));
		}
		LA8_: ;
	}
	LA4_: ;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genConv__NQxHzfwHfEh0YK3SZMpnIA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* d, NIM_BOOL downcast, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* source;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(d, IL64(36275087638309136));
	source = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087638309136));
	{
		NIM_BOOL T3_;
		NI diff;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*source).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		if (!(T3_)) goto LA4_;
		T3_ = ((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		LA4_: ;
		if (!T3_) goto LA5_;
		diff = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(dest, source);
		{
			if (!(diff == ((NI) 2147483647))) goto LA9_;
			result = n;
		}
		goto LA7_;
		LA9_: ;
		{
			if (!(diff < ((NI) 0))) goto LA12_;
			result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67), (*n).info, d);
			add__P8dDSotTW25BkfbyspojGg(result, n);
			{
				if (!downcast) goto LA16_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, (*n).info, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_3), TM__zwdrTKOAAM6OvWnXdBD4GQ_4);
			}
			LA16_: ;
		}
		goto LA7_;
		LA12_: ;
		{
			if (!(((NI) 0) < diff)) goto LA19_;
			result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66), (*n).info, d);
			add__P8dDSotTW25BkfbyspojGg(result, n);
			{
				if (!!(downcast)) goto LA23_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, (*n).info, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_6), TM__zwdrTKOAAM6OvWnXdBD4GQ_7);
			}
			LA23_: ;
		}
		goto LA7_;
		LA19_: ;
		{
			result = n;
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, methodCall__8CKh3oS3FPdX9cqBY8VV6MQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	disp = getDispatcher__L29cJgZ3WUDC7PfTSciv49cw((*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	{
		if (!!((disp == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		asgnRef((void**) (&(*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym), disp);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), genConv__NQxHzfwHfEh0YK3SZMpnIA((*result)._kind_6.sons->data[i], (*(*disp).typ).sons->data[i], NIM_TRUE, conf));
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T9_ = (NimStringDesc*)0;
		T10_ = (NimStringDesc*)0;
		T10_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*result)._kind_6.sons->data[((NI) 0)]);
		T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 21);
appendString(T9_, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_8));
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_9));
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__zwdrTKOAAM6OvWnXdBD4GQ_10, NIM_FALSE);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag, sameMethodBucket__leCAOmQx9bAqhpFuS2yXNVQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, NIM_BOOL multiMethods) {
	tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag result;
{	result = (tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag)0;
	{
		if (!!(((*(*a).name).Sup.id == (*(*b).name).Sup.id))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		NI T8_;
		T7_ = (NI)0;
		T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*a).typ);
		T8_ = (NI)0;
		T8_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*b).typ);
		if (!!((T7_ == T8_))) goto LA9_;
		goto BeforeRet_;
	}
	LA9_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*a).typ);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bb;
				if (!(i_2 < colontmp_)) goto LA13;
				i = i_2;
				aa = (*(*a).typ).sons->data[i];
				bb = (*(*b).typ).sons->data[i];
				{
					while (1) {
						aa = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aa, 2064);
						bb = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(bb, 2064);
						{
							NIM_BOOL T18_;
							T18_ = (NIM_BOOL)0;
							T18_ = ((*aa).kind == (*bb).kind);
							if (!(T18_)) goto LA19_;
							T18_ = ((*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
							LA19_: ;
							if (!T18_) goto LA20_;
							aa = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(aa);
							bb = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(bb);
						}
						goto LA16_;
						LA20_: ;
						{
							goto LA14;
						}
						LA16_: ;
					}
				} LA14: ;
				{
					NIM_BOOL T25_;
					T25_ = (NIM_BOOL)0;
					T25_ = sameType__3isNyHKb0U1OCnClmflXSg((*(*a).typ).sons->data[i], (*(*b).typ).sons->data[i], 0);
					if (!T25_) goto LA26_;
					{
						NIM_BOOL T30_;
						T30_ = (NIM_BOOL)0;
						T30_ = ((*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
						if (!(T30_)) goto LA31_;
						T30_ = !((result == ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 1)));
						LA31_: ;
						if (!T30_) goto LA32_;
						result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 2);
					}
					LA32_: ;
				}
				goto LA23_;
				LA26_: ;
				{
					NIM_BOOL T35_;
					NIM_BOOL T36_;
					NIM_BOOL T39_;
					NI diff;
					T35_ = (NIM_BOOL)0;
					T36_ = (NIM_BOOL)0;
					T36_ = ((*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
					if (!(T36_)) goto LA37_;
					T36_ = ((*bb).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
					LA37_: ;
					T35_ = T36_;
					if (!(T35_)) goto LA38_;
					T39_ = (NIM_BOOL)0;
					T39_ = (i == ((NI) 1));
					if (T39_) goto LA40_;
					T39_ = multiMethods;
					LA40_: ;
					T35_ = T39_;
					LA38_: ;
					if (!T35_) goto LA41_;
					diff = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(bb, aa);
					{
						if (!(diff < ((NI) 0))) goto LA45_;
						{
							if (!!((result == ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 1)))) goto LA49_;
							result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 2);
						}
						goto LA47_;
						LA49_: ;
						{
							result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 0);
							goto BeforeRet_;
						}
						LA47_: ;
					}
					goto LA43_;
					LA45_: ;
					{
						NIM_BOOL T53_;
						T53_ = (NIM_BOOL)0;
						T53_ = !((diff == ((NI) 2147483647)));
						if (!(T53_)) goto LA54_;
						T53_ = !(((((*a).flags | (*b).flags) &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0));
						LA54_: ;
						if (!T53_) goto LA55_;
						result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 1);
					}
					goto LA43_;
					LA55_: ;
					{
						result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 0);
						goto BeforeRet_;
					}
					LA43_: ;
				}
				goto LA23_;
				LA41_: ;
				{
					result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 0);
					goto BeforeRet_;
				}
				LA23_: ;
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
	{
		if (!(result == ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 2))) goto LA61_;
		{
			NIM_BOOL T65_;
			T65_ = (NIM_BOOL)0;
			T65_ = sameTypeOrNil__3isNyHKb0U1OCnClmflXSg_2((*(*a).typ).sons->data[((NI) 0)], (*(*b).typ).sons->data[((NI) 0)], 0);
			if (!!(T65_)) goto LA66_;
			{
				NIM_BOOL T70_;
				T70_ = (NIM_BOOL)0;
				T70_ = !(((*(*b).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T70_)) goto LA71_;
				T70_ = ((*(*(*b).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
				LA71_: ;
				if (!T70_) goto LA72_;
				asgnRef((void**) (&(*(*b).typ).sons->data[((NI) 0)]), (*(*a).typ).sons->data[((NI) 0)]);
			}
			goto LA68_;
			LA72_: ;
			{
				result = ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 0);
				goto BeforeRet_;
			}
			LA68_: ;
		}
		LA66_: ;
	}
	LA61_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, attachDispatcher__IMb6oKnI7Z7MRoHmAsuW3g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dispatcher) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*s).ast);
		if (!(((NI) 8) < T3_)) goto LA4_;
		asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 8)]), dispatcher);
	}
	goto LA1_;
	LA4_: ;
	{
		asgnRef((void**) (&(*(*s).ast)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*s).ast)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 9)));
		{
			if (!((*(*s).ast)._kind_6.sons->data[((NI) 7)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA9_;
			asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 7)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*s).info));
		}
		LA9_: ;
		asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 8)]), dispatcher);
	}
	LA1_: ;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, fixupDispatcher__UnAnE9bJg1GOV6YuCjrHPfg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* meth, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T5_;
		NI T7_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*disp).ast);
		T4_ = (((NI) 7) < T5_);
		if (!(T4_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast((*meth).ast);
		T4_ = (((NI) 7) < T7_);
		LA6_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = ((*(*(*disp).ast)._kind_6.sons->data[((NI) 7)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		LA8_: ;
		if (!T3_) goto LA9_;
		asgnRef((void**) (&(*(*disp).ast)._kind_6.sons->data[((NI) 7)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*meth).ast)._kind_6.sons->data[((NI) 7)]));
	}
	LA9_: ;
	{
		if (!((*(*disp).typ).lockLevel == ((NI16) -1))) goto LA13_;
		(*(*disp).typ).lockLevel = (*(*meth).typ).lockLevel;
	}
	goto LA11_;
	LA13_: ;
	{
		NIM_BOOL T16_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T20_;
		NimStringDesc* T21_;
		T16_ = (NIM_BOOL)0;
		T16_ = !(((*(*meth).typ).lockLevel == ((NI16) -1)));
		if (!(T16_)) goto LA17_;
		T16_ = !(((*(*meth).typ).lockLevel == (*(*disp).typ).lockLevel));
		LA17_: ;
		if (!T16_) goto LA18_;
		nimZeroMem((void*)T20_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T20_[0] = dollar___75vsOXLrqmx5LmVlMWaymw((*(*meth).typ).lockLevel);
		T20_[1] = dollar___75vsOXLrqmx5LmVlMWaymw((*(*disp).typ).lockLevel);
		T21_ = (NimStringDesc*)0;
		T21_ = nsuFormatOpenArray(((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_11), T20_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*meth).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 45), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__zwdrTKOAAM6OvWnXdBD4GQ_12, NIM_FALSE);
		{
			if (!((*(*disp).typ).lockLevel < (*(*meth).typ).lockLevel)) goto LA24_;
			(*(*disp).typ).lockLevel = (*(*meth).typ).lockLevel;
		}
		LA24_: ;
	}
	goto LA11_;
	LA18_: ;
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createDispatcher__L29cJgZ3WUDC7PfTSciv49cw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	disp = copySym__lIu8wX6Beq6dBJgESOFFjg(s);
	(*disp).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 29)) & 63);
	(*disp).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1)) & 63));
	asgnRef((void**) (&(*disp).typ), copyType__4O4aYoscFPo2FRSh4rP9ayg((*disp).typ, (*(*disp).typ).owner, NIM_FALSE));
	{
		if (!((*(*disp).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5))) goto LA3_;
		(*(*disp).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0);
	}
	LA3_: ;
	asgnRef((void**) (&(*disp).ast), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast));
	asgnRef((void**) (&(*(*disp).ast)._kind_6.sons->data[((NI) 6)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*s).info));
	asgnRef((void**) (&(*disp).loc.r), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	{
		if (!!(((*(*s).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA7_;
		{
			NI T11_;
			T11_ = (NI)0;
			T11_ = len__P89cqdlERShb9alU3iC0yj8wast((*disp).ast);
			if (!(((NI) 7) < T11_)) goto LA12_;
			asgnRef((void**) (&(*(*(*disp).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym), copySym__lIu8wX6Beq6dBJgESOFFjg((*(*(*s).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym));
		}
		goto LA9_;
		LA12_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
			T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T15_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*s).info);
			add__P8dDSotTW25BkfbyspojGg((*disp).ast, T15_);
		}
		LA9_: ;
	}
	LA7_: ;
	T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T16_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(disp);
	attachDispatcher__IMb6oKnI7Z7MRoHmAsuW3g(s, T16_);
	T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T17_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(disp);
	attachDispatcher__IMb6oKnI7Z7MRoHmAsuW3g(disp, T17_);
	result = disp;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, methodDef__NKjYu87vB0uQmGRMfpDEBQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL fromCache) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* witness;
	tyTuple__quA39a2QdEQU9cSEIUSibApQ T20_;
	NI T21_;
{	witness = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*g).methods ? (*g).methods->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp;
				tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag T5_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				disp = (*g).methods->data[i].Field1;
				T5_ = (tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag)0;
				T5_ = sameMethodBucket__leCAOmQx9bAqhpFuS2yXNVQ(disp, s, (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 43))&63U)))!=0));
				switch (T5_) {
				case ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 2):
				{
					NI T7_;
					asgnRef((void**) (&(*g).methods->data[i].Field0), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*g).methods->data[i].Field0), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
					T7_ = (*g).methods->data[i].Field0->Sup.len++;
					asgnRef((void**) (&(*g).methods->data[i].Field0->data[T7_]), s);
					attachDispatcher__IMb6oKnI7Z7MRoHmAsuW3g(s, (*(*disp).ast)._kind_6.sons->data[((NI) 8)]);
					fixupDispatcher__UnAnE9bJg1GOV6YuCjrHPfg(s, disp, (*g).config);
					checkMethodEffects__r9asNVglvzXEd9bIUN8ENKaA(g, disp, s);
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = ((1048580 & (*s).flags) == 1048576);
						if (!(T10_)) goto LA11_;
						T10_ = !(((*g).methods->data[i].Field0->data[((NI) 0)] == s));
						LA11_: ;
						if (!T10_) goto LA12_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_13), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__zwdrTKOAAM6OvWnXdBD4GQ_14, NIM_FALSE);
					}
					LA12_: ;
					goto BeforeRet_;
				}
				break;
				case ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 0):
				{
				}
				break;
				case ((tyEnum_MethodResult__qJetbm7aUauL2eZA6Gt5Ag) 1):
				{
					{
						if (!(witness == 0)) goto LA18_;
						witness = (*g).methods->data[i].Field0->data[((NI) 0)];
					}
					LA18_: ;
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	nimZeroMem((void*)(&T20_), sizeof(tyTuple__quA39a2QdEQU9cSEIUSibApQ));
	T20_.Field0 = (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) newSeq((&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), 1);
	asgnRef((void**) (&T20_.Field0->data[0]), s);
	T20_.Field1 = createDispatcher__L29cJgZ3WUDC7PfTSciv49cw_2(s);
	asgnRef((void**) (&(*g).methods), (tySequence__bWZXqEvLFwhLvAqSRoFNgQ*) incrSeqV3((TGenericSeq*)((*g).methods), (&NTI__bWZXqEvLFwhLvAqSRoFNgQ_)));
	T21_ = (*g).methods->Sup.len++;
	genericSeqAssign((&(*g).methods->data[T21_].Field0), T20_.Field0, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_));
	asgnRef((void**) (&(*g).methods->data[T21_].Field1), T20_.Field1);
	{
		NimStringDesc* T26_;
		NimStringDesc* T27_;
		if (!!((witness == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA24_;
		T26_ = (NimStringDesc*)0;
		T27_ = (NimStringDesc*)0;
		T27_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*g).config, (*witness).info);
		T26_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + (T27_ ? T27_->Sup.len : 0) + 68);
appendString(T26_, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_15));
appendString(T26_, (*(*s).name).s);
appendString(T26_, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_16));
appendString(T26_, T27_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__zwdrTKOAAM6OvWnXdBD4GQ_17, NIM_FALSE);
	}
	goto LA22_;
	LA24_: ;
	{
		if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20))&63U)))!=0))) goto LA29_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 26), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__zwdrTKOAAM6OvWnXdBD4GQ_18, NIM_FALSE);
	}
	goto LA22_;
	LA29_: ;
	LA22_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, relevantCol__VyTMs9bvAKVadESEVcZjTAg)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ* methods, NI col) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (NIM_BOOL)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*methods->data[((NI) 0)]).typ).sons->data[col], IL64(36275087638268176));
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = ((methods ? methods->Sup.len : 0)-1);
			colontmp_ = T6_;
			res = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2;
					if (!(res <= colontmp_)) goto LA8;
					i = res;
					t2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*methods->data[i]).typ).sons->data[col], IL64(36275087638268176));
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = sameType__3isNyHKb0U1OCnClmflXSg(t2, t, 0);
						if (!!(T11_)) goto LA12_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA12_: ;
					res += ((NI) 1);
				} LA8: ;
			}
		}
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpSignatures__rUZr5XojrKzIvIaAqdTDew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols) {
	NI result;
{	result = (NI)0;
	{
		NI col;
		NI colontmp_;
		NI i;
		col = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*a).typ);
		i = ((NI) 1);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA3;
				col = i;
				{
					NIM_BOOL T6_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bb;
					NI d;
					T6_ = (NIM_BOOL)0;
					T6_ = contains__R6uRTGpl30Ofaw4Ni3vawA(relevantCols, col);
					if (!T6_) goto LA7_;
					aa = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*a).typ).sons->data[col], IL64(36275087638268176));
					bb = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*b).typ).sons->data[col], IL64(36275087638268176));
					d = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(aa, bb);
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = !((d == ((NI) 2147483647)));
						if (!(T11_)) goto LA12_;
						T11_ = !((d == ((NI) 0)));
						LA12_: ;
						if (!T11_) goto LA13_;
						result = d;
						goto BeforeRet_;
					}
					LA13_: ;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, sortBucket__deGdLjtRTwqb9cmLid4ujVA)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** a, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols) {
	NI n;
	NI T1_;
	NI h;
	T1_ = ((*a) ? (*a)->Sup.len : 0);
	n = T1_;
	h = ((NI) 1);
	{
		while (1) {
			h = (NI)((NI)(((NI) 3) * h) + ((NI) 1));
			{
				if (!(n < h)) goto LA6_;
				goto LA2;
			}
			LA6_: ;
		}
	} LA2: ;
	{
		while (1) {
			h = (NI)(h / ((NI) 3));
			{
				NI i;
				NI i_2;
				i = (NI)0;
				i_2 = h;
				{
					while (1) {
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
						NI j;
						if (!(i_2 < n)) goto LA12;
						i = i_2;
						v = (*a)->data[i];
						j = i;
						{
							while (1) {
								NI T15_;
								T15_ = (NI)0;
								T15_ = cmpSignatures__rUZr5XojrKzIvIaAqdTDew((*a)->data[(NI)(j - h)], v, relevantCols);
								if (!(((NI) 0) <= T15_)) goto LA14;
								asgnRef((void**) (&(*a)->data[j]), (*a)->data[(NI)(j - h)]);
								j = (NI)(j - h);
								{
									if (!(j < h)) goto LA18_;
									goto LA13;
								}
								LA18_: ;
							} LA14: ;
						} LA13: ;
						asgnRef((void**) (&(*a)->data[j]), v);
						i_2 += ((NI) 1);
					} LA12: ;
				}
			}
			{
				if (!(h == ((NI) 1))) goto LA22_;
				goto LA8;
			}
			LA22_: ;
		}
	} LA8: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, genDispatcher__fxC8K5IpbgysfOghKezEGw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tySequence__DfgJFJEYoj4YBAHLZPl5lQ* methods, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* relevantCols) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* base;
	NI paramLen;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nilchecks;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* disp;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ands;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iss;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boolType;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	base = (*(*(*methods->data[((NI) 0)]).ast)._kind_6.sons->data[((NI) 8)])._kind_4.sym;
	result = base;
	paramLen = len__5mJADrRYkP3r9auuiuDZN9cQast((*base).typ);
	nilchecks = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*base).info);
	disp = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), (*base).info);
	ands = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_19), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109));
	iss = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_20), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 15));
	boolType = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
	{
		NI col;
		NI i;
		col = (NI)0;
		i = ((NI) 1);
		{
			while (1) {
				if (!(i < paramLen)) goto LA3;
				col = i;
				{
					NIM_BOOL T6_;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					T6_ = (NIM_BOOL)0;
					T6_ = contains__R6uRTGpl30Ofaw4Ni3vawA(relevantCols, col);
					if (!T6_) goto LA7_;
					param = (*(*(*(*base).typ).n)._kind_6.sons->data[col])._kind_4.sym;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
						tyArray__AB6yfoUgfWM2NtGe9bzkCmw T14_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T15_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
						T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*param).typ, IL64(36134350135273744));
						if (!((*T11_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T11_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA12_;
						nimZeroMem((void*)T14_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
						T15_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T15_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA(g, ((NimStringDesc*) &TM__zwdrTKOAAM6OvWnXdBD4GQ_21));
						T14_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T15_);
						T14_[1] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(param);
						T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T16_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T14_, 2);
						add__P8dDSotTW25BkfbyspojGg(nilchecks, T16_);
					}
					LA12_: ;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI meth;
		NI colontmp_;
		NI T18_;
		NI res;
		meth = (NI)0;
		colontmp_ = (NI)0;
		T18_ = ((methods ? methods->Sup.len : 0)-1);
		colontmp_ = T18_;
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* curr;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retTyp;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T38_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ret;
				if (!(res <= colontmp_)) goto LA20;
				meth = res;
				curr = methods->data[meth];
				cond = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				{
					NI col_2;
					NI i_2;
					col_2 = (NI)0;
					i_2 = ((NI) 1);
					{
						while (1) {
							if (!(i_2 < paramLen)) goto LA23;
							col_2 = i_2;
							{
								NIM_BOOL T26_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* isn;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param_2;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T30_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
								T26_ = (NIM_BOOL)0;
								T26_ = contains__R6uRTGpl30Ofaw4Ni3vawA(relevantCols, col_2);
								if (!T26_) goto LA27_;
								isn = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*base).info, boolType);
								T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T29_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(iss);
								add__P8dDSotTW25BkfbyspojGg(isn, T29_);
								param_2 = (*(*(*(*base).typ).n)._kind_6.sons->data[col_2])._kind_4.sym;
								T30_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T30_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(param_2);
								add__P8dDSotTW25BkfbyspojGg(isn, T30_);
								T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T31_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*base).info, (*(*curr).typ).sons->data[col_2]);
								add__P8dDSotTW25BkfbyspojGg(isn, T31_);
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
									if (!!((cond == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA34_;
									a = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*base).info, boolType);
									T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T36_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(ands);
									add__P8dDSotTW25BkfbyspojGg(a, T36_);
									add__P8dDSotTW25BkfbyspojGg(a, cond);
									add__P8dDSotTW25BkfbyspojGg(a, isn);
									cond = a;
								}
								goto LA32_;
								LA34_: ;
								{
									cond = isn;
								}
								LA32_: ;
							}
							LA27_: ;
							i_2 += ((NI) 1);
						} LA23: ;
					}
				}
				retTyp = (*(*base).typ).sons->data[((NI) 0)];
				call = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*base).info, retTyp);
				T38_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T38_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(curr);
				add__P8dDSotTW25BkfbyspojGg(call, T38_);
				{
					NI col_3;
					NI i_3;
					col_3 = (NI)0;
					i_3 = ((NI) 1);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
							if (!(i_3 < paramLen)) goto LA41;
							col_3 = i_3;
							T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T42_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*(*(*base).typ).n)._kind_6.sons->data[col_3])._kind_4.sym);
							T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T43_ = genConv__NQxHzfwHfEh0YK3SZMpnIA(T42_, (*(*curr).typ).sons->data[col_3], NIM_FALSE, (*g).config);
							add__P8dDSotTW25BkfbyspojGg(call, T43_);
							i_3 += ((NI) 1);
						} LA41: ;
					}
				}
				ret = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T48_;
					if (!!((retTyp == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA46_;
					a_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), (*base).info);
					T48_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T48_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*(*base).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym);
					add__P8dDSotTW25BkfbyspojGg(a_2, T48_);
					add__P8dDSotTW25BkfbyspojGg(a_2, call);
					ret = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109), (*base).info);
					add__P8dDSotTW25BkfbyspojGg(ret, a_2);
				}
				goto LA44_;
				LA46_: ;
				{
					ret = call;
				}
				LA44_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_3;
					if (!!((cond == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA52_;
					a_3 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), (*base).info);
					add__P8dDSotTW25BkfbyspojGg(a_3, cond);
					add__P8dDSotTW25BkfbyspojGg(a_3, ret);
					add__P8dDSotTW25BkfbyspojGg(disp, a_3);
				}
				goto LA50_;
				LA52_: ;
				{
					disp = ret;
				}
				LA50_: ;
				res += ((NI) 1);
			} LA20: ;
		}
	}
	add__P8dDSotTW25BkfbyspojGg(nilchecks, disp);
	(*nilchecks).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5)) & 31);
	asgnRef((void**) (&(*(*result).ast)._kind_6.sons->data[((NI) 6)]), nilchecks);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, generateMethodDispatchers__7t0GJlNQwZyLt0Kz3RhRdw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
	{
		NI bucket;
		NI colontmp_;
		NI T2_;
		NI i;
		bucket = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*g).methods ? (*g).methods->Sup.len : 0);
		colontmp_ = T2_;
		i = ((NI) 0);
		{
			while (1) {
				tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg relevantCols;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T17_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
				if (!(i < colontmp_)) goto LA4;
				bucket = i;
				nimZeroMem((void*)(&relevantCols), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
				initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&relevantCols));
				{
					NI col;
					NI colontmp__2;
					NI i_2;
					col = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast((*(*g).methods->data[bucket].Field0->data[((NI) 0)]).typ);
					i_2 = ((NI) 1);
					{
						while (1) {
							if (!(i_2 < colontmp__2)) goto LA7;
							col = i_2;
							{
								NIM_BOOL T10_;
								T10_ = (NIM_BOOL)0;
								T10_ = relevantCol__VyTMs9bvAKVadESEVcZjTAg((*g).methods->data[bucket].Field0, col);
								if (!T10_) goto LA11_;
								incl__jENnK9c9bPE73pKmo2vYjpqg((&relevantCols), col);
							}
							LA11_: ;
							{
								if (!!((((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 43))&63U)))!=0))) goto LA15_;
								goto LA5;
							}
							LA15_: ;
							i_2 += ((NI) 1);
						} LA7: ;
					}
				} LA5: ;
				sortBucket__deGdLjtRTwqb9cmLid4ujVA((&(*g).methods->data[bucket].Field0), (&relevantCols));
				T17_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T17_ = genDispatcher__fxC8K5IpbgysfOghKezEGw(g, (*g).methods->data[bucket].Field0, (&relevantCols));
				T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T18_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T17_);
				add__P8dDSotTW25BkfbyspojGg(result, T18_);
				i += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
